@@ -36,7 +36,7 @@
 **********************************************************************
   This class will be our OpenGL widget of three geometric objects
 *********************************************************************/
-class Object_Display:public Gtk_GLArea
+class Object_Display:public Gtk::GLArea
   {private:
      GLint cube,sphere,cylinder;
      bool flag_cube,flag_sphere,flag_cylinder;
@@ -61,14 +61,14 @@ class Object_Display:public Gtk_GLArea
      virtual gint button_press_event_impl(GdkEventButton*); 
  
      // callbacks we will connect to other widgets
-     void toggle_cube(Gtk_ToggleButton *button);
-     void toggle_sphere(Gtk_ToggleButton *button);
-     void toggle_cylinder(Gtk_ToggleButton *button);
+     void toggle_cube(Gtk::ToggleButton *button);
+     void toggle_sphere(Gtk::ToggleButton *button);
+     void toggle_cylinder(Gtk::ToggleButton *button);
 
      // signals to update buttons 
-     Signal1<bool>set_cube;
-     Signal1<bool>set_sphere;
-     Signal1<bool>set_cylinder;
+     SigC::Signal1<void,bool>set_cube;
+     SigC::Signal1<void,bool>set_sphere;
+     SigC::Signal1<void,bool>set_cylinder;
   };
 
 /***********************************************************
@@ -86,7 +86,7 @@ class Object_Display:public Gtk_GLArea
   (the show signal happens before realization and should 
    not be used.)
 ***********************************************************/
-Object_Display::Object_Display():Gtk_GLArea() 
+Object_Display::Object_Display():Gtk::GLArea() 
   {
    cube=sphere=cylinder=0;
    flag_cube=flag_sphere=flag_cylinder=0;
@@ -103,7 +103,7 @@ void Object_Display::realize_impl()
   {
    // we must call the real realize_impl so the object is 
    // marked realized
-   Gtk_GLArea::realize_impl();
+   Gtk::GLArea::realize_impl();
 
    // then we can call our init
    initgl();
@@ -120,16 +120,15 @@ gint Object_Display::expose_event_impl(GdkEventExpose *event)
 gint Object_Display::configure_event_impl(GdkEventConfigure *event)
   {
    if (make_current())
-     {
-      setupgl();
-     }
+     setupgl();
    return TRUE;
   }
 
 
 // Function has not been test (as far as I know)
 Object_Display::~Object_Display()
-  {if (glIsList(cube)==GL_TRUE)
+  {
+   if (glIsList(cube)==GL_TRUE)
      glDeleteLists(cube,1);
    if (glIsList(sphere)==GL_TRUE)
      glDeleteLists(sphere,1);
@@ -455,17 +454,17 @@ gint Object_Display::button_press_event_impl(GdkEventButton *event)
   }
 
 // call backs that we will connect the buttons to.
-void Object_Display::toggle_cube(Gtk_ToggleButton *button)
+void Object_Display::toggle_cube(Gtk::ToggleButton *button)
   {flag_cube=button->get_active();
    drawgl();
   }
 
-void Object_Display::toggle_sphere(Gtk_ToggleButton *button)
+void Object_Display::toggle_sphere(Gtk::ToggleButton *button)
   {flag_sphere=button->get_active();
    drawgl();
   }
 
-void Object_Display::toggle_cylinder(Gtk_ToggleButton *button)
+void Object_Display::toggle_cylinder(Gtk::ToggleButton *button)
   {flag_cylinder=button->get_active();
    drawgl();
   }
@@ -476,23 +475,21 @@ void Object_Display::toggle_cylinder(Gtk_ToggleButton *button)
   This class will be our MainWindow containing an OpenGL window 
   and a toolbox to manipulate the OpenGL object. 
 *********************************************************************/
-Gtk_Main *app;
-
-class MainWindowClass : public Gtk_Window 
+class MainWindowClass : public Gtk::Window 
   {private:
      // Pointers to all of the widgets
-     Gtk_Button *button;
-     Gtk_ToggleButton *button_cube;
-     Gtk_ToggleButton *button_sphere;
-     Gtk_ToggleButton *button_cylinder;
-     Gtk_Frame *frame;
-     Gtk_Table *table;
+     Gtk::Button *button;
+     Gtk::ToggleButton *button_cube;
+     Gtk::ToggleButton *button_sphere;
+     Gtk::ToggleButton *button_cylinder;
+     Gtk::Frame *frame;
+     Gtk::Table *table;
      Object_Display *display;
    public:
       MainWindowClass (void);
       ~MainWindowClass (void);
       gint delete_event_impl(GdkEventAny *) 
-        {app->quit();
+        {Gtk::Main::quit();
          return 0;
         }
   };
@@ -505,7 +502,7 @@ class MainWindowClass : public Gtk_Window
   than top down.)  View the file layout.ps for a description
   of the widget relations.
 ***********************************************************/
-MainWindowClass::MainWindowClass(void) : Gtk_Window(GTK_WINDOW_TOPLEVEL)
+MainWindowClass::MainWindowClass(void) : Gtk::Window(GTK_WINDOW_TOPLEVEL)
   {
    set_title("Pick Me");
  
@@ -514,31 +511,31 @@ MainWindowClass::MainWindowClass(void) : Gtk_Window(GTK_WINDOW_TOPLEVEL)
    display->set_usize(300,300);
    display->show();
 
-   // Gtk_GLArea can't have a border, so we will stick it in a frame
-   frame = new Gtk_Frame();
+   // Gtk::GLArea can't have a border, so we will stick it in a frame
+   frame = new Gtk::Frame();
    frame->set_shadow_type (GTK_SHADOW_IN);
    frame->set_border_width(10);  
-   frame->add(display);   
+   frame->add(*display);   
    frame->show();
 
    // Create a Quit button
-   button_cube = new Gtk_ToggleButton("Cube");
+   button_cube = new Gtk::ToggleButton("Cube");
    button_cube->set_usize(100,50);
    button_cube->set_border_width(5);
    button_cube->show();
 
-   button_sphere = new Gtk_ToggleButton("Sphere");
+   button_sphere = new Gtk::ToggleButton("Sphere");
    button_sphere->set_usize(100,50);
    button_sphere->set_border_width(5);
    button_sphere->show();
 
-   button_cylinder = new Gtk_ToggleButton("Cylinder");
+   button_cylinder = new Gtk::ToggleButton("Cylinder");
    button_cylinder->set_usize(100,50);
    button_cylinder->set_border_width(5);
    button_cylinder->show();
 
    // Create a Quit button
-   button = new Gtk_Button("Quit");
+   button = new Gtk::Button("Quit");
    button->set_usize(100,50);
    button->set_border_width(10);
    button->show();
@@ -546,7 +543,7 @@ MainWindowClass::MainWindowClass(void) : Gtk_Window(GTK_WINDOW_TOPLEVEL)
    // Place the Scrollbars and Button in a Table
    // I was using attach_defaults, but it is better if just the scrollbars 
    // grow, to fill the space.
-   table = new Gtk_Table(2,4,FALSE);
+   table = new Gtk::Table(2,4,FALSE);
    table->attach(*frame,0,1,0,4,GTK_EXPAND|GTK_FILL);
    table->attach(*button_cube,1,2,0,1,GTK_SHRINK);
    table->attach(*button_sphere,1,2,1,2,GTK_SHRINK);
@@ -558,26 +555,29 @@ MainWindowClass::MainWindowClass(void) : Gtk_Window(GTK_WINDOW_TOPLEVEL)
    table->show();
 
    // Add the box to the mainwindow
-   add(table);
+   add(*table);
 
    // Connect the Quit button to the application quit
-   connect_to_method(button->clicked,app,&Gtk_Main::quit);
+   button->clicked.connect(Gtk::Main::quit.slot());
 
    // Connect buttons to the OpenGL object
-   connect_to_method(button_cube->toggled,display,
-                     &Object_Display::toggle_cube,button_cube);
-   connect_to_method(button_sphere->toggled,display,
-                     &Object_Display::toggle_sphere,button_sphere);
-   connect_to_method(button_cylinder->toggled,display,
-                     &Object_Display::toggle_cylinder,button_cylinder);
+   button_cube->toggled
+      .connect(bind(slot(display,&Object_Display::toggle_cube),
+                    button_cube));
+   button_sphere->toggled
+      .connect(bind(slot(display,&Object_Display::toggle_sphere),
+                    button_sphere));
+   button_cylinder->toggled
+      .connect(bind(slot(display,&Object_Display::toggle_cylinder),
+                    button_cylinder));
  
    // Connect the OpenGL object back to the buttons 
-   connect_to_method(display->set_cube,button_cube,
-                     &Gtk_ToggleButton::set_active);
-   connect_to_method(display->set_sphere,button_sphere,
-                     &Gtk_ToggleButton::set_active);
-   connect_to_method(display->set_cylinder,button_cylinder,
-                     &Gtk_ToggleButton::set_active);
+   display->set_cube    .connect(slot(button_cube,
+                                      &Gtk::ToggleButton::set_active));
+   display->set_sphere  .connect(slot(button_sphere,
+                                      &Gtk::ToggleButton::set_active));
+   display->set_cylinder.connect(slot(button_cylinder,
+                                      &Gtk::ToggleButton::set_active));
   }
 
 MainWindowClass::~MainWindowClass(void)
@@ -600,12 +600,12 @@ gint main(gint argc, gchar **argv)
   {
    MainWindowClass *main_window;
   
-   app = new Gtk_Main(&argc,&argv);
+   Gtk::Main app(argc,argv);
 
    main_window = new MainWindowClass;
    main_window->show();
   
-   app->run();
+   Gtk::Main::run();
 
    return(0);
   }
